@@ -23,7 +23,7 @@ def run_job(project_id, tag, exclude_tag=''):
                 },
                 'maxResources': None,
                 'forQualification': False,
-                'projectId': project_id
+                'projectId': project_id,
             }
         }
     }
@@ -40,7 +40,7 @@ def list_jobs(project_id):
     r = make_request(url)
     data = r.json()['data']
     for j in data:
-        del (j['relationships'])
+        del j['relationships']
     return data
 
 
@@ -58,7 +58,7 @@ def create_job_export_file(job_id, raw, worker_data):
                 "jobId": f'{job_id}',
                 "type": 'raw' if raw else 'target',
                 "allJudgements": worker_data and not raw,
-                "includeWorkerData": worker_data and not raw
+                "includeWorkerData": worker_data and not raw,
             }
         }
     }
@@ -75,7 +75,7 @@ def detail_job(job_id):
     url = f'/jobs/{job_id}?'
     r = make_request(url)
     data = r.json()['data']
-    del(data['relationships'])
+    del data['relationships']
     return data
 
 
