@@ -2,7 +2,7 @@ import argparse
 import logging
 from datetime import datetime
 from django.utils.text import slugify
-from tasq_cli import jobs, export_files
+from tasq_cli import jobs, export_files, credentials
 from tasq_cli import projects
 from tasq_cli import settings
 from tasq_cli.upload import do_upload, create_csv_from_currently_uploaded_files, upload_csv
@@ -11,6 +11,7 @@ from tasq_cli.upload import do_upload, create_csv_from_currently_uploaded_files,
 def main():
     parser = argparse.ArgumentParser(prog='tasq')
     parser.add_argument('-V', '--version', action='version', version=f'Tasq CLI {settings.VERSION}')
+    parser.add_argument('-cf', '--config-file', action='store', help='use non-default config file')
     parser.add_argument('-d', '--dataset-name', action='store', help='set current dataset name')
     parser.add_argument('-c', '--client-id', action='store', help='override client id')
     parser.add_argument('-b', '--bucket-name', action='store', help='override bucket name')
@@ -24,6 +25,7 @@ def main():
     images_parser = subparsers.add_parser('upload', help='upload files')
     images_parser.add_argument('-p', '--path', default=False, help='path to directory with images')
     images_parser.add_argument('-e', '--exclude', help='File extensions to exclude.', action='append', nargs='*')
+    images_parser.add_argument('-u', '--url-prefix', action='store', help='specify the prefix of files to upload')
     images_parser.add_argument('--dry', help='create upload file but dont actually upload anything', action='store_true')
 
     csv_parser = subparsers.add_parser('create-csv', help='create csv for files that were already uploaded')
@@ -62,13 +64,12 @@ def main():
 
     list_projects_parser = subparsers.add_parser('list-projects', help='list all projects')
 
-    get_export_link = subparsers.add_parser('get-export-link',
-                                                       help='get a link to an export file, which is '
-                                                            'not necessarily populated yet')
+    get_export_link = subparsers.add_parser(
+        'get-export-link', help='get a link to an export file, which is not necessarily populated yet'
+    )
     get_export_link.add_argument('export_file_id', help='the export file id')
 
-    get_export_file = subparsers.add_parser('get-export-file',
-                                                help='get export file details')
+    get_export_file = subparsers.add_parser('get-export-file', help='get export file details')
     get_export_file.add_argument('export_file_id', help='the export file id')
 
     args = parser.parse_args()
@@ -80,21 +81,23 @@ def main():
 
     logger.info(f'Tasq CLI {settings.VERSION}')
 
+    credentials.load_credentials(args.config_file)  # If not specified, loads from default config path
+
     # override client id if flag is present
     if args.client_id:
-        settings.CLIENT_ID = args.client_id
-        logger.info(f'Overriding client id with {settings.CLIENT_ID}')
+        credentials.CLIENT_ID = args.client_id
+        logger.info(f'Overriding client id with {credentials.CLIENT_ID}')
 
     # override bucket name if flag is present
     if args.bucket_name:
         if args.bucket_name == 'tasq':
             logger.info('Setting default bucket name gits-active-storage')
-            settings.BUCKET = 'gits-active-storage'
+            credentials.BUCKET = 'gits-active-storage'
             logger.info('Setting CDN_URL to cdn.tasq.ai')
             settings.CDN_URL = 'https://cdn.tasq.ai/{object_name}'
         else:
-            settings.BUCKET = args.bucket_name
-            logger.info(f'Overriding bucket name with {settings.BUCKET}')
+            credentials.BUCKET = args.bucket_name
+            logger.info(f'Overriding bucket name with {credentials.BUCKET}')
 
     if args.dataset_name:
         DATASET_NAME = slugify(f'{args.dataset_name}')
@@ -111,11 +114,16 @@ def main():
             logger.error('Path to upload is required.')
             exit(1)
 
+        if args.url_prefix:
+            settings.CDN_URL = f'{args.url_prefix}/{{object_name}}'
+        elif credentials.URL_PREFIX:
+            settings.CDN_URL = f'{credentials.URL_PREFIX}/{{object_name}}'
+
         settings.dry = args.dry
         do_upload(DATASET_NAME, args.path, args.exclude, settings)
 
     if args.action == 'create-csv':
-        create_csv_from_currently_uploaded_files(args.csv_dataset_name, args.file_name, settings) 
+        create_csv_from_currently_uploaded_files(args.csv_dataset_name, args.file_name, settings)
 
     if args.action == 'upload-csv':
         upload_csv(args.file_name, args.project_id, args.tag)
