@@ -13,7 +13,9 @@ def get_config_directory():
     return tasq_dir
 
 
-def get_config_file_path():
+def get_config_file_path(config_file_path=None):
+    if config_file_path:
+        return config_file_path
     return os.path.join(get_config_directory(), 'config.ini')
 
 
@@ -31,16 +33,18 @@ def write_default_config():
         config.write(f)
 
 
-def get_credentials():
-    if not os.path.isfile(get_config_file_path()):
+def get_credentials(config_file_path=None):
+    config_file_path = get_config_file_path(config_file_path)
+    if not os.path.isfile(config_file_path):
         write_default_config()
 
     config = configparser.ConfigParser()
-    config.read(get_config_file_path())
+    config.read(config_file_path)
 
     return {
         'client_id': config.get('credentials', 'client_id', fallback=''),
         'bucket_name': config.get('credentials', 'bucket_name', fallback=''),
+        'url_prefix': config.get('credentials', 'url_prefix', fallback=''),
         'access_key': config.get('credentials', 'access_key', fallback=''),
         'secret_key': config.get('credentials', 'secret_key', fallback=''),
         'token': config.get('credentials', 'token', fallback=''),
